@@ -30,11 +30,11 @@ impl Executor for &mut SqliteConnection {
         where
             E: Execute<'q, Self::Database>,
     {
-        let sql = query.sql();
+        let sql = query.sql().to_owned();
         let arguments = query.take_arguments();
         let persistent = query.persistent() && arguments.is_some();
         let s = self.worker
-            .execute(sql, arguments, self.row_channel_size, persistent);
+            .execute(&sql, arguments, self.row_channel_size, persistent);
         if s.is_err() {
             let c = ChanStream::new(|sender|
                 Err(s.err().unwrap())
@@ -52,12 +52,11 @@ impl Executor for &mut SqliteConnection {
         where
             E: Execute<'q, Self::Database>,
     {
-        let sql = query.sql();
         let arguments = query.take_arguments();
         let persistent = query.persistent() && arguments.is_some();
         let mut stream = self
             .worker
-            .execute(sql, arguments, self.row_channel_size, persistent)?;
+            .execute(query.sql(), arguments, self.row_channel_size, persistent)?;
         let mut stream = executor_mut::sender_to_stream(stream);
         use crate::cdbc::io::chan_stream::TryStream;
         while let Some(res) = stream.try_next()? {
@@ -72,7 +71,7 @@ impl Executor for &mut SqliteConnection {
         &mut self,
         sql: &'q str,
         _parameters: &[SqliteTypeInfo],
-    ) -> Result<SqliteStatement<'q>, Error>
+    ) -> Result<SqliteStatement, Error>
         where
     {
         let statement = self.worker.prepare(sql)?;
