@@ -23,6 +23,10 @@ impl Database for Sqlite {
     type TypeInfo = SqliteTypeInfo;
 
     type Value = SqliteValue;
+
+    fn holder() -> &'static str {
+        "?"
+    }
 }
 
 impl<'r> HasValueRef<'r> for Sqlite {
@@ -39,10 +43,10 @@ impl<'q> HasArguments<'q> for Sqlite {
     type ArgumentBuffer = Vec<SqliteArgumentValue<'q>>;
 }
 
-impl<'q> HasStatement<'q> for Sqlite {
+impl HasStatement for Sqlite {
     type Database = Sqlite;
 
-    type Statement = SqliteStatement<'q>;
+    type Statement = SqliteStatement;
 }
 
 impl HasStatementCache for Sqlite {}
